rm(list=ls())
install.packages(".../TAG_0.1.0.tar.gz", repos = NULL, type="source")


library(TAG)
n <- 20 #sample size
d <- 2  #dimension of input
NN <- 100 #simulation times
N <- 1000 #testset size
set.seed(2)
r <- sample(1:10000, NN) #random seed
one <- matrix(1, nrow=n)
Ide <- diag(1, n)
par.m <- matrix(0,ncol=(3+2*d),nrow=NN)
par.omega <- matrix(0,ncol=2*d,nrow=NN)


#target function
f  <- function(x){
  exp(2*sin(0.5*pi*x[1]) + 0.5*cos(2.5*pi*x[2]))
}

aa = 1
for(aa in 1:NN){
  library(randtoolbox)
  xx <- sobol(n, dim = d, init = TRUE, scrambling = 2, seed = r[aa], normal = FALSE)
  n <- nrow(xx)
  YY <- rep(0,length=n)
  for(i in 1:n){
    YY[i] <- f(xx[i,])
  }


  ####Generate testing dataset
  X.test <- sobol(N, dim = d, init = TRUE, scrambling = 2, seed = r[aa], normal = FALSE)
  ytrue  <- rep(0,length=nrow(xx))
  for(i in 1:nrow(X.test)){
    ytrue[i] <- f(X.test[i,])
  }

  ####StepA: Give initial values
  ini.TAG <- Initial.TAG(Res=YY, Input=xx)

  ####StepB: Construct TAG
  par.TAG <- TAG(IniTAG = ini.TAG)

  ####StepC: Construct TAAG and predict
  #initial values for product part
  library(DiceKriging)
  set.seed(2)
  temp.m <- km(formula=~1, design=xx, response=par.TAG$TrRes, covtype="gauss",nugget = (10^-15), multistart = 5)
  theta.vv <- sqrt(2*(coef(temp.m)$range^2))

  par.TAAG <- TAAG(parTAG = par.TAG, nu.est=theta.vv)
  pre.TAAG <- pred.TAAG(parTAAG=par.TAAG, newX=X.test)


  ####Record
  par.m[aa,] <- c(sqrt(mean((ytrue-(pre.TAAG$Prediction))^2)),
                  par.TAAG$lambda, par.TAAG$omega,
                  par.TAAG$s2, par.TAAG$eta)

  print(c(aa,par.TAAG$omega,par.TAAG$s2,par.TAAG$eta,sqrt(mean((ytrue-(pre.TAAG$Prediction))^2))))

}

library(mlegp)
par.GPfit <- par.ok <- matrix(0,nrow=NN,ncol=2)
for(aa in 1:NN){
  ####Generate Datasets
  xx <-  sobol(n, dim = d, init = TRUE, scrambling = 2, seed = r[aa], normal = FALSE)
  YY <- rep(0,length=n)
  for(i in 1:n){
    YY[i] <- f(xx[i,])
  }
  m <- mlegp(xx,YY)
  par.ok[aa,] <- 1/sqrt(m$beta)
  1/sqrt(m$beta)

}



par(mfrow=c(1,3), mgp=c(3,1,0), mar=c(6,3,6,4))
colnames(par.m) <- c("MSPE","lambda",paste0("omega",1:d),paste0("s",1:d), "eta")
boxplot(par.ok, main="GP", cex.main=2.5,cex.lab=2,cex.axis=2,ylim=c(0,1.95), names = c(expression(s[1]),expression(s[2])))
axis(4,at=c(0.185,0.555, 0.925, 1.295 ,1.665),labels=c("More Important", expression(symbol("\254")),
                                                       expression(symbol("\254")), expression(symbol("\254")),
                                                       "Less Important"), cex.main=2.5,cex.lab=2,cex.axis=2)
boxplot(par.m[,5:6], main="TAG length scale",cex.main=2.5,cex.lab=2,cex.axis=2,ylim=c(0,1.95),names=c(expression(s[1]),expression(s[2])))
boxplot(par.m[,3:4], main="TAG weights",names=c(expression(omega[1]),expression(omega[2])), ylim=c(0,0.95),
        cex.main=2.5,cex.lab=2,cex.axis=2)
axis(4,at=c(0.1,0.3, 0.5, 0.7 ,0.9),labels=c("Less Important", expression(symbol("\256")),
                                             expression(symbol("\256")), expression(symbol("\256")),
                                             "More Important"),cex.main=2.5,cex.lab=2,cex.axis=2)


